import React from 'react'
import IngredientsList from './ingredients-list'
import Instructions from './instructions'
import StarRating from './star-rating';
import Summary from './summary';
import {graphql, createFragmentContainer} from 'react-relay';
import changeRecipeRate from '../mutations/change-recipe-rate';

const Recipe = ({recipe}) => {
  const onRate = rating => {
    changeRecipeRate(rating, recipe.id);
  }
  const {name, ingredients, instructions, rating} = recipe;
  return (
    <section id={name.toLowerCase().replace(/\s/g, '-')}>
      <h2>{name}</h2>
      <IngredientsList list={ingredients}/>
      <Instructions title="Cooking Instructions" list={instructions}/>
      <StarRating starsSelected={rating} onRate={onRate}/>
      <Summary
        ingredientsCount={ingredients.length}
        instructionsCount={instructions.length} />
    </section>
  )
}

export default createFragmentContainer(
  Recipe,
  graphql`
    fragment recipe_recipe on Recipe {
      id
      name
      ingredients {
        name
        amount
        measurement
      }
      instructions
      rating
    }
  `
);
