import {commitMutation, graphql} from 'react-relay';
import environment from '../environment';
import {ConnectionHandler} from 'relay-runtime';

export default (recipe) => {
  const {name, ingredients, instructions, rating} = recipe;
  const variables = {
    input: {
      name,
      ingredients,
      instructions,
      rating,
    }
  };
  return commitMutation(
    environment,
    {
      mutation: graphql`
        mutation addRecipe_Mutation($input: AddRecipeInput!) {
          addRecipe(input: $input) {
            recipe {
              id
              name
              ingredients {
                name
                amount
                measurement
              }
              instructions
              rating
            }
          }
        }
      `,
      variables,
      updater: store => {
        const {getConnection, createEdge, insertEdgeAfter} = ConnectionHandler;
        const rootField = store.getRootField('addRecipe');
        const recipe = rootField.getLinkedRecord('recipe');
        const root = store.getRoot();
        const recipes = getConnection(root, 'app_Query_recipes');
        const edge = createEdge(store, recipes, recipe, 'RecipeEdge');
        insertEdgeAfter(recipes, edge);
      },
      onError: err => console.error(err)
    }
  )
}
